==> qtjambi-serialbus-debuginfo-linux-x64-6.5.3.jar: sources/QtJambiSerialBus/QCanFrameProcessor_ParseResult_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtSerialBus/qcanframeprocessor.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiSerialBus/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QCanFrameProcessor_ParseResult(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QCanFrameProcessor::ParseResult")
    QCanFrameProcessor::ParseResult *_ptr = reinterpret_cast<QCanFrameProcessor::ParseResult *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QCanFrameProcessor_ParseResult_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QCanFrameProcessor::ParseResult *__qt_this = new(__qtjambi_ptr) QCanFrameProcessor::ParseResult();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QCanFrameProcessor::ParseResult
void __qt_destruct_QCanFrameProcessor_ParseResult(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QCanFrameProcessor::ParseResult")
    reinterpret_cast<QCanFrameProcessor::ParseResult*>(ptr)->~ParseResult();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QCanFrameProcessor::ParseResult::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanFrameProcessor_00024ParseResult_initialize_1native__Lio_qt_serialbus_QCanFrameProcessor_00024ParseResult_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCanFrameProcessor::ParseResult::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCanFrameProcessor_ParseResult_0, sizeof(QCanFrameProcessor::ParseResult), typeid(QCanFrameProcessor::ParseResult), false, &deleter_QCanFrameProcessor_ParseResult, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QCanFrameProcessor::ParseResult::operator==(QCanFrameProcessor::ParseResult,QCanFrameProcessor::ParseResult)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanFrameProcessor_00024ParseResult_operator_1equal_1native_1cref_1QCanFrameProcessor_1ParseResult__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID value21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QCanFrameProcessor::ParseResult *__qt_this = QtJambiAPI::objectFromNativeId<QCanFrameProcessor::ParseResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCanFrameProcessor::ParseResult::operator==(QCanFrameProcessor::ParseResult,QCanFrameProcessor::ParseResult)", __qt_this)
        const QCanFrameProcessor::ParseResult& __qt_value21 = QtJambiAPI::valueReferenceFromNativeId<QCanFrameProcessor::ParseResult>(value21);
        __java_return_value = (*__qt_this) == __qt_value21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanFrameProcessor_00024ParseResult_setSignalValues_1native_1cref_1QMap__JLjava_util_Map_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject signalValues0)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCanFrameProcessor::ParseResult *__qt_this = QtJambiAPI::objectFromNativeId<QCanFrameProcessor::ParseResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QMap<QString, QVariant>&  __qt_signalValues0 = qtjambi_cast<const QMap<QString, QVariant>& >(__jni_env, __qtjambi_scope, signalValues0);
        __qt_this->signalValues = __qt_signalValues0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanFrameProcessor_00024ParseResult_signalValues_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCanFrameProcessor::ParseResult *__qt_this = QtJambiAPI::objectFromNativeId<QCanFrameProcessor::ParseResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QMap<QString, QVariant>&  __qt_value = __qt_this->signalValues;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanFrameProcessor_00024ParseResult_setUniqueId_1native_1cref_1QtCanBus_1UniqueId__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint uniqueId0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCanFrameProcessor::ParseResult *__qt_this = QtJambiAPI::objectFromNativeId<QCanFrameProcessor::ParseResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QtCanBus::UniqueId __qt_uniqueId0 = qtjambi_cast<QtCanBus::UniqueId>(__jni_env, uniqueId0);
        __qt_this->uniqueId = QtCanBus::UniqueId(__qt_uniqueId0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanFrameProcessor_00024ParseResult_uniqueId_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCanFrameProcessor::ParseResult *__qt_this = QtJambiAPI::objectFromNativeId<QCanFrameProcessor::ParseResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QtCanBus::UniqueId&  __qt_value = __qt_this->uniqueId;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanFrameProcessor_00024ParseResult_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QCanFrameProcessor::ParseResult *__qt_this = QtJambiAPI::objectFromNativeId<QCanFrameProcessor::ParseResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanFrameProcessor_00024ParseResult_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QCanFrameProcessor::ParseResult *__qt_this = QtJambiAPI::objectFromNativeId<QCanFrameProcessor::ParseResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QCanFrameProcessor_ParseResult(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QCanFrameProcessor::ParseResult>("QCanFrameProcessor::ParseResult", "io/qt/serialbus/QCanFrameProcessor$ParseResult");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QCanFrameProcessor_ParseResult, {
        ConstructorInfo(&__qt_construct_QCanFrameProcessor_ParseResult_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QCanFrameProcessor_ParseResult);
    registerMetaType<QCanFrameProcessor::ParseResult>("QCanFrameProcessor::ParseResult");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-serialbus-debuginfo-linux-x64-6.6.1.jar: sources/QtJambiSerialBus/QCanFrameProcessor_ParseResult_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtSerialBus/qcanframeprocessor.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiSerialBus/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QCanFrameProcessor_ParseResult(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QCanFrameProcessor::ParseResult")
    QCanFrameProcessor::ParseResult *_ptr = reinterpret_cast<QCanFrameProcessor::ParseResult *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QCanFrameProcessor_ParseResult_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QCanFrameProcessor::ParseResult *__qt_this = new(__qtjambi_ptr) QCanFrameProcessor::ParseResult();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QCanFrameProcessor::ParseResult
void __qt_destruct_QCanFrameProcessor_ParseResult(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QCanFrameProcessor::ParseResult")
    reinterpret_cast<QCanFrameProcessor::ParseResult*>(ptr)->~ParseResult();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QCanFrameProcessor::ParseResult::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanFrameProcessor_00024ParseResult_initialize_1native__Lio_qt_serialbus_QCanFrameProcessor_00024ParseResult_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCanFrameProcessor::ParseResult::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCanFrameProcessor_ParseResult_0, sizeof(QCanFrameProcessor::ParseResult), typeid(QCanFrameProcessor::ParseResult), false, &deleter_QCanFrameProcessor_ParseResult, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QCanFrameProcessor::ParseResult::operator==(QCanFrameProcessor::ParseResult,QCanFrameProcessor::ParseResult)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanFrameProcessor_00024ParseResult_equals_1native_1cref_1QCanFrameProcessor_1ParseResult__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID value21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QCanFrameProcessor::ParseResult *__qt_this = QtJambiAPI::objectFromNativeId<QCanFrameProcessor::ParseResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCanFrameProcessor::ParseResult::operator==(QCanFrameProcessor::ParseResult,QCanFrameProcessor::ParseResult)", __qt_this)
        const QCanFrameProcessor::ParseResult& __qt_value21 = QtJambiAPI::valueReferenceFromNativeId<QCanFrameProcessor::ParseResult>(value21);
        __java_return_value = (*__qt_this) == __qt_value21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanFrameProcessor_00024ParseResult_setSignalValues_1native_1cref_1QMap__JLjava_util_Map_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject signalValues0)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCanFrameProcessor::ParseResult *__qt_this = QtJambiAPI::objectFromNativeId<QCanFrameProcessor::ParseResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QMap<QString, QVariant>&  __qt_signalValues0 = qtjambi_cast<const QMap<QString, QVariant>& >(__jni_env, __qtjambi_scope, signalValues0);
        __qt_this->signalValues = __qt_signalValues0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanFrameProcessor_00024ParseResult_signalValues_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCanFrameProcessor::ParseResult *__qt_this = QtJambiAPI::objectFromNativeId<QCanFrameProcessor::ParseResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QMap<QString, QVariant>&  __qt_value = __qt_this->signalValues;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanFrameProcessor_00024ParseResult_setUniqueId_1native_1cref_1QtCanBus_1UniqueId__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint uniqueId0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCanFrameProcessor::ParseResult *__qt_this = QtJambiAPI::objectFromNativeId<QCanFrameProcessor::ParseResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QtCanBus::UniqueId __qt_uniqueId0 = qtjambi_cast<QtCanBus::UniqueId>(__jni_env, uniqueId0);
        __qt_this->uniqueId = QtCanBus::UniqueId(__qt_uniqueId0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanFrameProcessor_00024ParseResult_uniqueId_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCanFrameProcessor::ParseResult *__qt_this = QtJambiAPI::objectFromNativeId<QCanFrameProcessor::ParseResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QtCanBus::UniqueId&  __qt_value = __qt_this->uniqueId;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanFrameProcessor_00024ParseResult_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QCanFrameProcessor::ParseResult *__qt_this = QtJambiAPI::objectFromNativeId<QCanFrameProcessor::ParseResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanFrameProcessor_00024ParseResult_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QCanFrameProcessor::ParseResult *__qt_this = QtJambiAPI::objectFromNativeId<QCanFrameProcessor::ParseResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QCanFrameProcessor_ParseResult(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QCanFrameProcessor::ParseResult>("QCanFrameProcessor::ParseResult", "io/qt/serialbus/QCanFrameProcessor$ParseResult");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QCanFrameProcessor_ParseResult, {
        ConstructorInfo(&__qt_construct_QCanFrameProcessor_ParseResult_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QCanFrameProcessor_ParseResult);
    registerMetaType<QCanFrameProcessor::ParseResult>("QCanFrameProcessor::ParseResult");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
